@@ -21,7 +21,7 @@ from elisa.core.common import application
 from elisa.core.media_uri import MediaUri
 from elisa.core.input_event import EventValue, key_values, num_values
 from elisa.core.components.model import Model
-from elisa.core.application import CONFIG_DIR, PICTURES_CACHE
+from elisa.core.default_config import CONFIG_DIR, PICTURES_CACHE
 from elisa.core.utils.cancellable_defer import CancellableDeferred, \
                                                CancelledError
 from elisa.core.utils.i18n import install_translation
@@ -59,6 +59,7 @@ import pickle
 
 
 _ = install_translation('flickr')
+_p = install_translation('poblesec')
 
 
 class FlickrEntryPointModel(Model):
@@ -86,6 +87,7 @@ def flickr_decorator(controller):
     link.controller_path = '/poblesec/flickr/home'
     link.label = _('Flickr')
     link.icon = 'elisa.plugins.flickr.logo'
+    controller.model.append(link)
     return defer.succeed(None)
 
 
@@ -224,7 +226,7 @@ class FlickrController(ControllerMixin, HierarchyController):
         deferred = super(FlickrController, self).initialize()
         self.uri = uri
 
-        def add_entries(self):
+        def add_entries(result):
             entries = [(_('Last 7 days interesting'), True,
                         'elisa.plugins.poblesec.recently_viewed_photos',
                         flickr.generate_call_uri(method='flickr.interestingness.getList')),
@@ -249,6 +251,13 @@ class FlickrController(ControllerMixin, HierarchyController):
             self.model.append(MyAccountAction(self))
             return self
 
+        def check_for_login_dfr(result):
+            provider = get_flickr_provider()
+            if provider.login_dfr is not None:
+                return provider.login_dfr
+
+        deferred.addCallback(check_for_login_dfr)
+
         if uri == self.start_uri:
             # List of the entry points
             deferred.addCallback(add_entries)
@@ -490,3 +499,35 @@ class FlickrAccountListSwitcherController(ListSwitcherController):
              FlickrAccountGridController]
     crumbs_logo = "elisa.plugins.flickr.crumbs_logo"
     default_mode = FlickrAccountPreviewListController
+
+
+def use_me_hook(frontend):
+    """
+    'Use me' hook that takes the user to the Pictures/Internet/Flickr section.
+
+    @param frontend: the current frontend (poblesec)
+    @type frontend:  L{elisa.plugins.pigment.pigment_frontend.PigmentFrontend}
+
+    @return:         a deferred fired when the action is complete
+    @rtype:          L{twisted.internet.defer.Deferred}
+    """
+    browser = frontend.retrieve_controllers('/poblesec/browser')[0]
+    browser.history.clear()
+
+    paths = [('/poblesec/pictures_menu', _p('Pictures')),
+             ('/poblesec/pictures/internet', _p('Internet')),
+             ('/poblesec/flickr/home', _('Flickr'))]
+
+    # Select the pictures section in Elisa's main menu
+    for index, link in enumerate(browser.history.current.model):
+        if link.controller_path == paths[0][0]:
+            browser.history.current.menu.selected_item_index = index
+            break
+
+    def append_controller_cb(result, path, label, **kwargs):
+        return browser.history.append_controller(path, label, **kwargs)
+
+    dfr = defer.succeed(None)
+    for path, label in paths:
+        dfr.addCallback(append_controller_cb, path, label)
+    return dfr
