@@ -91,10 +91,15 @@ class FlickrResourceProvider(ResourceProvider):
             failure.trap(ValueError)
             return self
 
-        dfr = self.login()
-        dfr.addCallback(lambda r: defer.succeed(self))
-        dfr.addErrback(got_error)
-        return dfr
+        def reset_login_dfr(result_or_failure):
+            self.login_dfr = None
+            return result_or_failure
+
+        self.login_dfr = self.login()
+        self.login_dfr.addErrback(got_error)
+        self.login_dfr.addBoth(reset_login_dfr)
+
+        return super(FlickrResourceProvider, self).initialize()
 
     def clean(self):
         """
@@ -103,6 +108,10 @@ class FlickrResourceProvider(ResourceProvider):
         close_dfrs = []
         # Close the API connection
         close_dfrs.append(self._api_client.close())
+
+        if self.login_dfr is not None:
+            close_dfrs.append(self.login_dfr)
+
         # Close all the image farm connections
         close_dfrs += [client.close() for client in self._img_clients.values()]
         dfr = defer.DeferredList(close_dfrs, consumeErrors=True)
