@@ -20,7 +20,7 @@
 Unit tests for the Flickr API helper functions.
 """
 
-from twisted.trial.unittest import TestCase
+from twisted.trial.unittest import TestCase, SkipTest
 
 from elisa.plugins.flickr.resource_provider import FlickrResourceProvider, \
                                                    API_SERVER
@@ -29,7 +29,12 @@ from elisa.plugins.flickr.models import FlickrPhotoModel
 
 from elisa.core.media_uri import MediaUri
 
-import hashlib
+try:
+    from hashlib import md5
+except ImportError:
+    # hashlib is new in Python 2.5
+    from md5 import md5
+
 from xml.dom import minidom
 import os.path
 import shutil
@@ -47,8 +52,8 @@ class TestFlickrAPIOffline(TestCase):
 
         # Simulate that the application is already authenticated
         def get_dummy_token_file():
-            return os.path.expanduser(os.path.join('~', '.flickr', 'dummy',
-                                                   'auth.xml'))
+            return os.path.join(os.path.abspath('.'),
+                    'flickr', 'dummy', 'auth.xml')
 
         flickr._get_token_file = get_dummy_token_file
 
@@ -64,9 +69,9 @@ class TestFlickrAPIOffline(TestCase):
                      'api_key': flickr._key}
         flickr.sign_arguments(arguments)
         self.failUnless('api_sig' in arguments.keys())
-        md5 = hashlib.md5(flickr._secret + 'api_key' + flickr._key + \
-                          'methodflickr.auth.getFrob').hexdigest()
-        self.failUnlessEqual(arguments['api_sig'], md5)
+        md5_sum = md5(flickr._secret + 'api_key' + flickr._key + \
+                      'methodflickr.auth.getFrob').hexdigest()
+        self.failUnlessEqual(arguments['api_sig'], md5_sum)
 
     def test_save_token(self):
         """
@@ -150,6 +155,7 @@ class TestFlickrAPIOnline(TestCase):
         flickr._get_token_file = self.get_token_file
 
     def setUp(self):
+        raise SkipTest("MANUAL TEST")
         self.provider = FlickrResourceProvider()
         return self.provider.initialize()
 
