@@ -24,6 +24,7 @@ from twisted.trial.unittest import TestCase
 from twisted.internet import defer
 
 from elisa.core.media_uri import MediaUri
+from elisa.core.utils.misc import run_functional_tests_check
 
 from elisa.plugins.base.models.image import ImageModel
 from elisa.plugins.base.models.media import RawDataModel
@@ -39,7 +40,7 @@ from elisa.core.resource_manager import NoMatchingResourceProvider
 
 import os.path
 import binascii
-import hashlib
+
 from xml.dom import minidom
 
 class TestFlickrResourceProvider(TestCase):
@@ -48,12 +49,21 @@ class TestFlickrResourceProvider(TestCase):
     This test case tests the FlickrResourceProvider class.
     """
 
+    token = "FAKE TOKEN"
+
+    def get_cached_token(self):
+        return self.token
+
     def setUp(self):
-        self.token = flickr.get_cached_token()
+        # patch get_cached_token
+        self._get_cached_token = flickr.get_cached_token
+        flickr.get_cached_token = self.get_cached_token
+
         self.provider = FlickrResourceProvider()
         return self.provider.initialize()
 
     def tearDown(self):
+        flickr.get_cached_token = self._get_cached_token
         return self.provider.clean()
 
     def test_invalid_get_uri(self):
@@ -87,6 +97,7 @@ class TestFlickrResourceProvider(TestCase):
         """
         Test a simple API call.
         """
+        run_functional_tests_check()
         method = 'flickr.test.echo'
         uri = flickr.generate_call_uri(method=method)
 
@@ -109,6 +120,7 @@ class TestFlickrResourceProvider(TestCase):
         """
         Test a simple API call without providing an API key.
         """
+        run_functional_tests_check()
         uri = 'http://%s/services/rest/?method=flickr.test.echo' % API_SERVER
         result_model, request_defer = self.provider.get(uri)
         self.failUnlessFailure(request_defer, ValueError)
@@ -131,6 +143,7 @@ class TestFlickrResourceProvider(TestCase):
         Test that the response model is correctly filled when the response to
         the query is a list of photos.
         """
+        run_functional_tests_check()
         user_id = '80651083@N00'
         uri = flickr.generate_call_uri(method='flickr.people.getPublicPhotos',
                                        arguments={'user_id': user_id})
@@ -150,6 +163,7 @@ class TestFlickrResourceProvider(TestCase):
         Test that the response model is correctly filled when the response to
         the query is a photo.
         """
+        run_functional_tests_check()
         photo_id = '2566013012'
         uri = flickr.generate_call_uri(method='flickr.photos.getInfo',
                                        arguments={'photo_id': photo_id})
@@ -170,6 +184,7 @@ class TestFlickrResourceProvider(TestCase):
         Test that the response model is correctly filled when the response to
         the query is a list of tags.
         """
+        run_functional_tests_check()
         uri = flickr.generate_call_uri(method='flickr.tags.getHotList')
 
         def got_response(response):
@@ -187,6 +202,7 @@ class TestFlickrResourceProvider(TestCase):
         Test that the response model is correctly filled when the response to
         the query is a list of sizes for a photo.
         """
+        run_functional_tests_check()
         photo_id = '2566013012'
         uri = flickr.generate_call_uri(method='flickr.photos.getSizes',
                                        arguments={'photo_id': photo_id})
@@ -206,6 +222,7 @@ class TestFlickrResourceProvider(TestCase):
         """
         Test retrieving an image from its complete URL.
         """
+        run_functional_tests_check()
         uri = 'http://farm4.%s/3051/2537816751_68be501931_m.jpg' % IMG_SERVER
         image_size = 15246
 
@@ -224,6 +241,7 @@ class TestFlickrResourceProvider(TestCase):
         """
         Test retrieving an image that does not exist.
         """
+        run_functional_tests_check()
         uri = 'http://farm1.%s/crap.jpg' % IMG_SERVER
 
         result_model, request_defer = self.provider.get(uri)
@@ -234,6 +252,7 @@ class TestFlickrResourceProvider(TestCase):
         """
         Test concurrent retrieval of multiple images from the same farm.
         """
+        run_functional_tests_check()
         first_uri = 'http://farm3.%s/2374/2541399644_f24a624438_m_d.jpg' % IMG_SERVER
         second_uri = 'http://farm3.%s/2169/2543964231_ed8ab99ae8_m_d.jpg' % IMG_SERVER
 
@@ -255,16 +274,15 @@ class TestFlickrResourceProvider(TestCase):
         Stress test for concurrent retrieval of multiple images from the same
         farm.
         """
+        run_functional_tests_check()
         root = 'http://farm4.%s/' % IMG_SERVER
         photos = ['3280/2586466863_b0a236a54f_t.jpg',
                   '3175/2587332686_bc0100ea1d_t.jpg',
                   '3163/2586300619_b85095a276_t.jpg',
                   '3143/2587121948_b0b7896346_t.jpg',
                   '3192/2588374913_5a494f5c6c_t.jpg',
-                  '3039/2586556431_27c160a96d_t.jpg',
                   '3108/2587180848_dd5cb077e8_t.jpg',
                   '3261/2587315128_08362d7d94_t.jpg',
-                  '3176/2587114710_8205bd4d39_t.jpg',
                   '3176/2587746349_a8ce3980a8_t.jpg',
                   '3147/2588189712_91c6d7cd18_t.jpg',
                   '3065/2586808340_e1a53b78c7_t.jpg',
@@ -278,18 +296,19 @@ class TestFlickrResourceProvider(TestCase):
 
         request_defers = []
         for photo in photos:
-            result_model, request_defer = self.provider.get(MediaUri(root + photo))
-            request_defers.append(request_defer)
-
-        for request_defer in request_defers:
+            uri = MediaUri(root + photo)
+            result_model, request_defer = self.provider.get(uri)
             request_defer.addCallback(request_done)
 
+            request_defers.append(request_defer)
+
         return defer.DeferredList(request_defers)
 
     def test_multiple_images_concurrent_retrieval(self):
         """
         Test concurrent retrieval of multiple images from different farms.
         """
+        run_functional_tests_check()
         first_uri = 'http://farm4.%s/3109/2543837561_420bcc199b_m_d.jpg' % IMG_SERVER
         second_uri = 'http://farm3.%s/2117/2537054688_fb9cc1f65b_m_d.jpg' % IMG_SERVER
 
@@ -320,6 +339,8 @@ class TestFlickrResourceProvider(TestCase):
         request_defer.addCallback(got_response)
         return request_defer
 
+    test_authenticated_api_call.skip = "Does not work with a fake token"
+
     def test_upload_then_delete_photo(self):
         """
         Test uploading a photo to the user account, and then deleting it.
@@ -347,10 +368,13 @@ class TestFlickrResourceProvider(TestCase):
         post_defer.addCallback(posted)
         return post_defer
 
+    test_upload_then_delete_photo.skip = "Does not work with a fake token"
+
     def test_upload_fails(self):
         """
         Test a failing photo upload.
         """
+        run_functional_tests_check()
         filename = os.path.join(os.path.dirname(__file__),
                                 'data', 'smiley.jpg')
         uri = 'http://%s/services/upload/' % API_SERVER
@@ -367,6 +391,7 @@ class TestFlickrResourceProvider(TestCase):
         Test cancelling a request when the server supports request pipelining.
         That is the case of the Flickr API server.
         """
+        run_functional_tests_check()
         method = 'flickr.test.echo'
         uri = flickr.generate_call_uri(method=method)
         request_deferreds = []
@@ -409,6 +434,7 @@ class TestFlickrResourceProvider(TestCase):
         Test cancelling a request when the server does not support request
         pipelining. That is the case of the image servers.
         """
+        run_functional_tests_check()
         root = 'http://farm4.%s/' % IMG_SERVER
         photos = ['3280/2586466863_b0a236a54f_t.jpg',
                   '3175/2587332686_bc0100ea1d_t.jpg',
