@@ -19,7 +19,7 @@
 from elisa.core.common import application
 from elisa.core.media_uri import MediaUri
 from elisa.core.components.model import Model
-from elisa.core.application import PICTURES_CACHE
+from elisa.core.default_config import PICTURES_CACHE
 from elisa.core.utils.i18n import install_translation
 
 from elisa.plugins.poblesec.link import Link
@@ -48,6 +48,7 @@ except ImportError:
 
 
 _ = install_translation('youtube')
+_p = install_translation('poblesec')
 
 
 class YoutubeVideoFeedModel(Model):
@@ -63,6 +64,7 @@ def youtube_decorator(controller):
     link.controller_path = '/poblesec/youtube'
     link.label = _('Youtube')
     link.icon = 'elisa.plugins.youtube.logo'
+    controller.model.append(link)
     return defer.succeed(None)
 
 
@@ -226,5 +228,36 @@ class YoutubeListSwitcherController(ListSwitcherController):
     modes = [YoutubePreviewListController,
              YoutubeCoverflowController,
              YoutubeGridController]
-    default_config ={'view_mode': 'preview_list'}
+    default_config = {'view_mode': 'preview_list'}
 
+
+def use_me_hook(frontend):
+    """
+    'Use me' hook that takes the user to the Video/Internet/Youtube section.
+
+    @param frontend: the current frontend (poblesec)
+    @type frontend:  L{elisa.plugins.pigment.pigment_frontend.PigmentFrontend}
+
+    @return:         a deferred fired when the action is complete
+    @rtype:          L{twisted.internet.defer.Deferred}
+    """
+    browser = frontend.retrieve_controllers('/poblesec/browser')[0]
+    browser.history.clear()
+
+    paths = [('/poblesec/video_menu', _p('Video')),
+             ('/poblesec/video/internet', _p('Internet')),
+             ('/poblesec/youtube', _('Youtube'))]
+
+    # Select the video section in Elisa's main menu
+    for index, link in enumerate(browser.history.current.model):
+        if link.controller_path == paths[0][0]:
+            browser.history.current.menu.selected_item_index = index
+            break
+
+    def append_controller_cb(result, path, label, **kwargs):
+        return browser.history.append_controller(path, label, **kwargs)
+
+    dfr = defer.succeed(None)
+    for path, label in paths:
+        dfr.addCallback(append_controller_cb, path, label)
+    return dfr
