@@ -22,15 +22,17 @@ setuptools script for the plugin.
 
 import os
 from setuptools import setup
-from elisa.core.utils.dist import find_packages, TrialTest, Clean, Distribution, build_po
+from elisa.core.utils.dist import find_packages, TrialTest, Clean, build_po
+
 
 packages, package_dir = find_packages(os.path.dirname(__file__))
 cmdclass = dict(test=TrialTest, clean=Clean, build_po=build_po)
 
+
 setup(name='elisa-plugin-youtube',
     version='0.1',
-    description='Youtube plugin',
-    long_description='Youtube resource provider for Elisa',
+    description='YouTube videos',
+    long_description='Browse, search and play YouTube videos.',
     license='GPLv3',
     author='Elisa Developers',
     author_email='elisa@lists.fluendo.com',
@@ -39,7 +41,7 @@ setup(name='elisa-plugin-youtube',
     namespace_packages=['elisa', 'elisa.plugins'],
     packages=packages,
     package_dir=package_dir,
-    package_data={'': ['*.png', '*.mo', '*.po', '*.conf'],
+    package_data={'': ['*.conf', 'icons/*'],
                   'elisa.plugins.youtube.i18n': ['*/LC_MESSAGES/*.po', '*.pot'],
                   },
     entry_points="""\
@@ -48,6 +50,9 @@ setup(name='elisa-plugin-youtube',
 
     [elisa.core.components.resource_provider]
     YoutubeResourceProvider = elisa.plugins.youtube.resource_provider:YoutubeResourceProvider
+
+    [elisa.core.plugin_registry]
+    use = elisa.plugins.youtube.controller:use_me_hook
     """,
     controller_mappings=[('/poblesec/youtube',
                           'elisa.plugins.youtube.controller:YoutubeListSwitcherController'),
